==> igniteui-webcomponents-core-4.0.2.tgz: package/esm2015/lib/LocalDataSourceDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { BaseDataSourceDescriptionMetadata } from "./BaseDataSourceDescriptionMetadata";
import { LocalDataSourceDescription } from "./LocalDataSourceDescription";
/**
 * @hidden
 */
export let LocalDataSourceDescriptionMetadata = /*@__PURE__*/ (() => {
    class LocalDataSourceDescriptionMetadata extends Base {
        static b(a) {
            if (LocalDataSourceDescriptionMetadata.a == null) {
                LocalDataSourceDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                LocalDataSourceDescriptionMetadata.c(LocalDataSourceDescriptionMetadata.a);
            }
            if (a.j(LocalDataSourceDescriptionMetadata.a)) {
                return;
            }
            a.y(LocalDataSourceDescriptionMetadata.a);
        }
        static c(a) {
            BaseDataSourceDescriptionMetadata.c(a);
            a.item("DataSourceRef", "(w:ItemsSource,xam:ItemsSource,j:dataSource,wf:ItemsSource)DataRef::object");
        }
        static d(a) {
            LocalDataSourceDescriptionMetadata.b(a);
            a.aa("LocalDataSource", () => new LocalDataSourceDescription());
            a.z("LocalDataSource", LocalDataSourceDescriptionMetadata.a);
        }
    }
    LocalDataSourceDescriptionMetadata.$t = /*@__PURE__*/ markType(LocalDataSourceDescriptionMetadata, 'LocalDataSourceDescriptionMetadata');
    LocalDataSourceDescriptionMetadata.a = null;
    return LocalDataSourceDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/LocalDataSourceDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { BaseDataSourceDescriptionMetadata } from "./BaseDataSourceDescriptionMetadata";
import { LocalDataSourceDescription } from "./LocalDataSourceDescription";
/**
 * @hidden
 */
export let LocalDataSourceDescriptionMetadata = /*@__PURE__*/ (() => {
    class LocalDataSourceDescriptionMetadata extends Base {
        static b(a) {
            if (LocalDataSourceDescriptionMetadata.a == null) {
                LocalDataSourceDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                LocalDataSourceDescriptionMetadata.c(LocalDataSourceDescriptionMetadata.a);
            }
            if (a.k(LocalDataSourceDescriptionMetadata.a)) {
                return;
            }
            a.aa(LocalDataSourceDescriptionMetadata.a);
        }
        static c(a) {
            BaseDataSourceDescriptionMetadata.c(a);
            a.item("DataSourceRef", "(w:ItemsSource,xam:ItemsSource,j:dataSource,wf:ItemsSource)DataRef::object");
        }
        static d(a) {
            LocalDataSourceDescriptionMetadata.b(a);
            a.ac("LocalDataSource", () => new LocalDataSourceDescription());
            a.ab("LocalDataSource", LocalDataSourceDescriptionMetadata.a);
        }
    }
    LocalDataSourceDescriptionMetadata.$t = /*@__PURE__*/ markType(LocalDataSourceDescriptionMetadata, 'LocalDataSourceDescriptionMetadata');
    LocalDataSourceDescriptionMetadata.a = null;
    return LocalDataSourceDescriptionMetadata;
})();
